/******************************************************************************
 * Copyright 2024 ztsh.eu                                                     *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License");            *
 * you may not use this file except in compliance with the License.           *
 * You may obtain a copy of the License at                                    *
 *                                                                            *
 *     http://www.apache.org/licenses/LICENSE-2.0                             *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 ******************************************************************************/

package eu.ztsh.lib.time.hazelcast;

import com.hazelcast.nio.serialization.ByteArraySerializer;
import eu.ztsh.lib.time.TimeRange;

import java.io.IOException;
import java.time.LocalDate;

import static eu.ztsh.lib.time.Formatters.yearMonthDay;

public class TimeRangeSerializer implements ByteArraySerializer<TimeRange> {

    @Override
    public byte[] write(TimeRange timeRange) throws IOException {
        return (yearMonthDay.format(timeRange.from()) + ":" + yearMonthDay.format(timeRange.to())).getBytes();
    }

    @Override
    public TimeRange read(byte[] bytes) throws IOException {
        var stringData = new String(bytes).split(":");
        return new TimeRange(parse(stringData[0]), parse(stringData[1]));
    }

    private static LocalDate parse(String input) {
        return LocalDate.parse(input, yearMonthDay);
    }

    @Override
    public int getTypeId() {
        return 150;
    }

}
